@@ -170,6 +170,7 @@ class RosGraph(Plugin):
         self._widget.quiet_check_box.clicked.connect(self._refresh_rosgraph)
         self._widget.unreachable_check_box.clicked.connect(self._refresh_rosgraph)
         self._widget.group_tf_check_box.clicked.connect(self._refresh_rosgraph)
+        self._widget.hide_dynamic_reconfigure_check_box.clicked.connect(self._refresh_rosgraph)
         self._widget.hide_tf_nodes_check_box.clicked.connect(self._refresh_rosgraph)
         self._widget.group_image_check_box.clicked.connect(self._refresh_rosgraph)
 
@@ -398,7 +399,7 @@ class RosGraph(Plugin):
         self._widget.group_image_check_box.setEnabled(False)
         self._widget.hide_dynamic_reconfigure_check_box.setEnabled(False)
 
-        self._update_graph_view(dotcode)
+        self._update_graph_view(dotcode.decode('utf-8'))
 
     def _fit_in_view(self):
         self._widget.graphics_view.fitInView(self._scene.itemsBoundingRect(), Qt.KeepAspectRatio)
@@ -413,7 +414,7 @@ class RosGraph(Plugin):
         if not handle.open(QIODevice.WriteOnly | QIODevice.Text):
             return
 
-        handle.write(self._current_dotcode)
+        handle.write(self._current_dotcode.encode())
         handle.close()
 
     def _save_svg(self):
